@@ -74,8 +74,6 @@ namespace KIO {
  * <pre>
  *   KDirOperator *op = new KDirOperator( KURL( "file:/home/gis" ), this );
  *   // some signals you might be interested in
- *   connect(op, SIGNAL(updateInformation(int, int)),
- *           SLOT(updateStatusLine(int, int)));
  *   connect(op, SIGNAL(urlEntered(const KURL&)),
  *           SLOT(urlEntered(const KURL&)));
  *   connect(op, SIGNAL(fileHighlighted(const KFileItem *)),
@@ -102,6 +100,15 @@ class KDirOperator : public QWidget
     Q_OBJECT
 
  public:
+    /**
+     * The various action types. These values can be or'd together
+     * @since 3.1
+     */
+    enum ActionTypes { SortActions = 1,
+                       ViewActions = 2,
+                       NavActions = 4,
+                       FileActions = 8,
+                       AllActions = 15 };
     /**
      * Constructs the KDirOperator with no initial view. As the views are
      * configurable, call @ref readConfig() to load the user's configuration
@@ -373,6 +380,43 @@ class KDirOperator : public QWidget
      */
     KActionCollection * actionCollection() const { return myActionCollection; }
 
+    /**
+     * Sets the config object and the to be used group in KDirOperator. This
+     * will be used to store the view's configuration via 
+     * @ref KFileView::writeConfig() (and for @ref KFileView::readConfig()).
+     * If you don't set this, the views cannot save and restore their 
+     * configuration.
+     *
+     * Usually you call this right after KDirOperator creation so that the view
+     * instantiation can make use of it already.
+     *
+     * Note that KDirOperator does NOT take ownership of that object (typically
+     * it's KGlobal::config() anyway.
+     *
+     * @see #viewConfig
+     * @see #viewConfigGroup
+     * @since 3.1
+     */
+    void setViewConfig( KConfig *config, const QString& group );
+    
+    /**
+     * Returns the KConfig object used for saving and restoring view's
+     * configuration.
+     * @returns the KConfig object used for saving and restoring view's
+     * configuration.
+     * @since 3.1
+     */
+    KConfig *viewConfig();
+
+    /**
+     * Returns the group name used for saving and restoring view's
+     * configuration.
+     * @returns the group name used for saving and restoring view's
+     * configuration.
+     * @since 3.1
+     */
+    QString viewConfigGroup() const;
+    
     /**
      * Reads the default settings for a view, i.e. the default KFile::FileView.
      * Also reads the sorting and whether hidden files should be shown.
@@ -383,6 +427,7 @@ class KDirOperator : public QWidget
      * to apply it.
      *
      * @see setView
+     * @see #setViewConfig
      * @see #writeConfig
      */
     virtual void readConfig( KConfig *, const QString& group = QString::null );
@@ -391,6 +436,7 @@ class KDirOperator : public QWidget
      * Saves the current settings like sorting, simple or detailed view.
      *
      * @see #readConfig
+     * @see #setViewConfig
      */
     virtual void writeConfig( KConfig *, const QString& group = QString::null );
 
@@ -433,6 +479,17 @@ class KDirOperator : public QWidget
     KIO::DeleteJob * del( const KFileItemList& items,
                           bool ask = true, bool showProgress = true );
 
+    /**
+     * Starts and returns a @ref KIO::DeleteJob to delete the given @p items.
+     *
+     * @param parent the parent widget used for the confirmation dialog
+     * @param ask specifies whether a confirmation dialog should be shown
+     * @param showProgress passed to the DeleteJob to show a progress dialog
+     * @since 3.1
+     */
+    KIO::DeleteJob * del( const KFileItemList& items, QWidget *parent,
+                          bool ask = true, bool showProgress = true );
+
     /**
      * Clears the forward and backward history.
      */
@@ -468,6 +525,12 @@ class KDirOperator : public QWidget
                  (mode & (KFile::File | KFile::Files)) == 0 );
     }
 
+    /**
+     * Sets up the action menu.
+     * @param actionTypes is an value of OR'd @ref ActionTypes that controls which actions to show in the action menu
+     */
+    void setupMenu(int whichActions);
+
 protected:
     /**
      * A view factory for creating predefined fileviews. Called internally by @ref #setView
@@ -515,6 +578,7 @@ protected:
     /**
      * Sets up the context-menu with all the necessary actions. Called from the
      * constructor, you usually don't need to call this.
+     * @since 3.1
      */
     void setupMenu();
 
@@ -686,9 +750,14 @@ signals:
      */
     void viewChanged( KFileView * newView );
 
-    void fileHighlighted(const KFileItem*);
-    void dirActivated(const KFileItem*);
-    void fileSelected(const KFileItem*);
+    /**
+     * Emitted when a file is highlighted or generally the selection changes in
+     * multiselection mode. In the latter case, @p item is 0L. You can access
+     * the selected items with @ref selectedItems().
+     */
+    void fileHighlighted( const KFileItem *item );
+    void dirActivated( const KFileItem *item );
+    void fileSelected( const KFileItem *item );
 
 private:
     /**
@@ -772,7 +841,6 @@ private slots:
     void slotSimpleView();
     void slotToggleHidden( bool );
 
-    void slotSingleView();
     void slotSeparateDirs();
     void slotDefaultPreview();
     void togglePreview( bool );
@@ -799,7 +867,10 @@ private slots:
     void slotRefreshItems( const KFileItemList& items );
 
     void slotProperties();
-
+    
+    void insertViewDependentActions();
+    
+private:
     static bool isReadable( const KURL& url );
 
 protected:
